@@ -83,7 +83,7 @@ int texteditor::load(const string abuf, const string id) {
 
     setfnum(newfn);
 
-    breakintolines(buf, lst, wrap ? x2-x1 : 0);
+    breakintolines(buf, lst, wrap ? x2-x1-1 : 0);
 
     curfile->lines->empty();
     for(i = lst.begin(); i != lst.end(); i++) {
@@ -248,7 +248,7 @@ int texteditor::addwindow(char *id) {
     ef->undo->freeitem = &undorecordfree;
 
     ef->markblock = new textblock;
-    memset(ef->markblock, 0, sizeof(ef->markblock));
+    memset(ef->markblock, 0, sizeof(textblock));
 
     ef->sx = ef->x = ef->sy = ef->y = 0;
     ef->modified = ef->markmode = ef->showmarked = false;
@@ -259,8 +259,7 @@ int texteditor::addwindow(char *id) {
     return files->count-1;
 }
 
-void texteditor::modification(tundoaction action, const string &data,
-bool connected = false, int curx = -1, int cury = -1) {
+void texteditor::modification(tundoaction action, const string &data, bool connected, int curx, int cury) {
     if(undolog && !data.empty()) {
 	undorecord *ur = new undorecord;
 	ur->x = curx < 0 ? CURCOL  : curx;
@@ -455,7 +454,7 @@ void texteditor::delmark() {
     textblock *mb = curfile->markblock;
 
     if(!mb->x1 && !mb->x2 && !mb->y1 && !mb->y2) return;
-    
+
     for(i = mb->y1; i <= mb->y2; i++) {
 	c = (char *) curfile->lines->at(i-line);
 	
@@ -503,14 +502,14 @@ void texteditor::delmark() {
     }
 
     modification(udelblock, deltext, false, mb->x1, mb->y1);
-    memset(curfile->markblock, 0, sizeof(struct textblock));
+    memset(curfile->markblock, 0, sizeof(textblock));
     setpos(newcol, newrow);
     draw();
 }
 
 void texteditor::clearmark() {
     CHECKLOADED;
-    memset(curfile->markblock, 0, sizeof(struct textblock));
+    memset(curfile->markblock, 0, sizeof(textblock));
     draw();
 }
 
@@ -778,7 +777,7 @@ int texteditor::count_clrcodes(char *cp, int pos) {
     return k;
 }
 
-void texteditor::showline(int ln, int startx, int distance, int extrax = 0) {
+void texteditor::showline(int ln, int startx, int distance, int extrax) {
     if(!show) return;
 
     int i, n, inscount, bcolor, sxinscount, printed, j, lastoccur, q, eolstart, npos, offs;
@@ -1043,7 +1042,7 @@ bool texteditor::fix_x(bool tab) {
     return osx != curfile->sx;
 }
 
-void texteditor::eddel(bool usetabs = true) {
+void texteditor::eddel(bool usetabs) {
     char *p = CURSTRING;
     int nextlen, todelete = 1, rm;
     string deltext;
@@ -1193,7 +1192,7 @@ void texteditor::eddelline() {
     updatecursor();
 }
 
-void texteditor::edenter(bool countspaces = true) {
+void texteditor::edenter(bool countspaces) {
     char *p = CURSTRING, *r;
     string spaceins;
     
@@ -1237,7 +1236,7 @@ void texteditor::edenter(bool countspaces = true) {
     edmove(KEY_DOWN);
 }
 
-void texteditor::edmove(int k, int options = EM_TAB) {
+void texteditor::edmove(int k, int options) {
     int i, lm;
     bool fdraw = false, acted;
     bool ctrlpressed = (options & EM_CTRL) && (getctrlkeys() & CONTROL_PRESSED);
@@ -1973,3 +1972,4 @@ bool hlight::operator != (const hl_kind &k) const {
 bool hlight::operator < (const hlight &ah) const {
     return kind == h_eol;
 }
+
