@@ -1,7 +1,7 @@
 /*
 *
 * kkstrtext string related and text processing routines
-* $Id: kkstrtext.cc,v 1.22 2002/03/21 17:44:41 konst Exp $
+* $Id: kkstrtext.cc,v 1.31 2002/12/12 14:26:06 konst Exp $
 *
 * Copyright (C) 1999-2002 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -137,7 +137,7 @@ string unmime(const string &text) {
     char *buf = new char[text.size()+1];
     strcpy(buf, text.c_str());
     r = unmime(buf);
-    delete buf;
+    delete[] buf;
     return r;
 }
 
@@ -145,6 +145,22 @@ string mime(const string &text) {
     string r;
     char *buf = new char[text.size()*3+1];
     r = mime(buf, text.c_str());
+    delete[] buf;
+    return r;
+}
+
+string fromutf8(const string &text) {
+    string r;
+    char *buf = (char *) utf8_to_str(text.c_str());
+    r = buf;
+    delete buf;
+    return r;
+}
+
+string toutf8(const string &text) {
+    string r;
+    char *buf = str_to_utf8(text.c_str());
+    r = buf;
     delete buf;
     return r;
 }
@@ -275,8 +291,7 @@ vector<int> getsymbolpositions(const string &haystack, const string &needles, co
 	continue; \
     }
 
-const char *strqpbrk(const char *s, int offset,
-const char *accept, const char *q, const char *esc = "") {
+const char *strqpbrk(const char *s, int offset, const char *accept, const char *q, const char *esc) {
     if(!s) return 0;
     if(!s[0]) return 0;
 
@@ -308,8 +323,7 @@ const char *accept, const char *q, const char *esc = "") {
     return ret;
 }
 
-const char *strqcasestr(const char *s, const char *str,
-const char *q, const char *esc = "") {
+const char *strqcasestr(const char *s, const char *str, const char *q, const char *esc) {
     char quote = 0;
     int i;
 
@@ -327,8 +341,7 @@ const char *q, const char *esc = "") {
     return 0;
 }
 
-const char *strqstr(const char *s, const char *str,
-const char *q, const char *esc = "") {
+const char *strqstr(const char *s, const char *str, const char *q, const char *esc) {
     char quote;
     const char *ret = 0, *p, *ss, *r;
     p = ss = s;
@@ -442,19 +455,20 @@ string textscreen(const string &text) {
     return r;
 }
 
-string leadcut(const string &base, const string &delim = "\t\n\r ") {
+string leadcut(const string &base, const string &delim) {
     int pos = base.find_first_not_of(delim);
     return (pos != -1) ? base.substr(pos) : "";
 }
 
-string trailcut(const string &base, const string &delim = "\t\n\r ") {
+string trailcut(const string &base, const string &delim) {
     int pos = base.find_last_not_of(delim);
     return (pos != -1) ? base.substr(0, pos+1) : "";
 }
 
-string getword(string &base, const string &delim = "\t\n\r ") {
+string getword(string &base, const string &delim) {
     string sub;
     int i;
+    bool found = false;
 
     base = leadcut(base, delim);
     
@@ -463,14 +477,15 @@ string getword(string &base, const string &delim = "\t\n\r ") {
 	sub.resize(i);
 	base.replace(0, i, "");
 	base = leadcut(base, delim);
+	found = true;
 	break;
     }
 
-    if(sub == base) base = "";
+    if(!found) base = "";
     return sub;
 }
 
-const string getwordquote(string &base, string quote = "\"", string delim = "\t\n\r ") {
+const string getwordquote(string &base, string quote, string delim) {
     string sub;
     bool inquote = false;
     int i;
@@ -492,7 +507,7 @@ const string getwordquote(string &base, string quote = "\"", string delim = "\t\
     return sub;
 }
 
-string getrword(string &base, const string &delim = "\t\n\r ") {
+string getrword(string &base, const string &delim) {
     string sub;
     int i;
 
@@ -510,7 +525,7 @@ string getrword(string &base, const string &delim = "\t\n\r ") {
     return sub;
 }
 
-string getrwordquote(string &base, const string &quote = "\"", const string &delim = "\t\n\r ") {
+string getrwordquote(string &base, const string &quote, const string &delim) {
     string sub;
     bool inquote = false;
     int i;
@@ -531,7 +546,7 @@ string getrwordquote(string &base, const string &quote = "\"", const string &del
     return sub;
 }
 
-int rtabmargin(bool fake, int curpos, const char *p = 0) {
+int rtabmargin(bool fake, int curpos, const char *p) {
     int ret = -1, n, near;
 
     if(p && (curpos != strlen(p))) {
@@ -553,7 +568,7 @@ int rtabmargin(bool fake, int curpos, const char *p = 0) {
     return ret;
 }
 
-int ltabmargin(bool fake, int curpos, const char *p = 0) {
+int ltabmargin(bool fake, int curpos, const char *p) {
     int ret = -1, near, n = 0;
     const char *cp;
     
@@ -600,7 +615,10 @@ void breakintolines(string text, vector<string> &lst, int linelen) {
 		    if(dpos) nlen = dpos; else nlen = 1;
 		}
 
-		sub = i->substr(nlen + ((dpos != -1) ? 1 : 0));
+		if(dpos != -1)
+		    nlen++;
+
+		sub = i->substr(nlen);
 		i->erase(nlen);
 		lst.insert(i+1, sub);
 		i = lst.begin();
@@ -666,8 +684,8 @@ const string &quote, const string &escape) {
     }
 }
 
-int find_quoted(const string &str, const string &needle, int offs = 0,
-const string &quote = "\"'", const string &escape = "\\") {
+int find_quoted(const string &str, const string &needle, int offs,
+const string &quote, const string &escape) {
     vector<quotedblock> positions;
     vector<quotedblock>::iterator qi;
     int npos = offs;
@@ -686,8 +704,8 @@ const string &quote = "\"'", const string &escape = "\\") {
     return !found ? npos : -1;
 }
 
-int find_quoted_first_of(const string &str, const string &needle, int offs = 0,
-const string &quote = "\"'", const string &escape = "\\") {
+int find_quoted_first_of(const string &str, const string &needle, int offs,
+const string &quote, const string &escape) {
     vector<quotedblock> positions;
     vector<quotedblock>::iterator qi;
     int npos = offs;
@@ -706,7 +724,7 @@ const string &quote = "\"'", const string &escape = "\\") {
     return !found ? npos : -1;
 }
 
-void splitlongtext(string text, vector<string> &lst, int size = 440, const string cont = "\n[continued]") {
+void splitlongtext(string text, vector<string> &lst, int size, const string cont) {
     string sub;
     int npos;
 
@@ -734,11 +752,11 @@ void splitlongtext(string text, vector<string> &lst, int size = 440, const strin
     }
 }
 
-string strdateandtime(time_t stamp, const string &fmt = "") {
+string strdateandtime(time_t stamp, const string &fmt) {
     return strdateandtime(localtime(&stamp), fmt);
 }
 
-string strdateandtime(struct tm *tms, const string &fmt = "") {
+string strdateandtime(struct tm *tms, const string &fmt) {
     char buf[512];
     time_t current_time = time(0);
     time_t when = mktime(tms);
@@ -782,7 +800,7 @@ int hex2int(const string ahex) {
     return r;
 }
 
-bool getconf(string &st, string &buf, ifstream &f, bool passemptylines = false) {
+bool getconf(string &st, string &buf, ifstream &f, bool passemptylines) {
     bool ret = false;
     static string sect;
 
@@ -859,7 +877,7 @@ string ruscase(const string &s, const string &mode) {
     return r;
 }
 
-string iconv(const string &text, const string &fromcs, const string &tocs) {
+string siconv(const string &text, const string &fromcs, const string &tocs) {
 #ifdef HAVE_ICONV_H
     iconv_t cd = iconv_open(tocs.c_str(), fromcs.c_str());
 
@@ -874,7 +892,7 @@ string iconv(const string &text, const string &fromcs, const string &tocs) {
 	soutleft = outleft = inleft*4;
 	soutbuf = outbuf = new char[outleft];
 
-	iconv(cd,
+	size_t res = iconv(cd,
 #ifdef ICONV_CONST
 	    (const char **)
 #endif
@@ -882,8 +900,12 @@ string iconv(const string &text, const string &fromcs, const string &tocs) {
 
 	iconv_close(cd);
 
-	soutbuf[soutleft-outleft] = 0;
-	r = soutbuf;
+	if(res != -1) {
+	    soutbuf[soutleft-outleft] = 0;
+	    r = soutbuf;
+	} else {
+	    r = text;
+	}
 
 	delete soutbuf;
 	delete sinbuf;
@@ -912,6 +934,9 @@ string cuthtml(const string &html, bool cutbrs) {
 	    if((tag == "br") || (tag == "BR")) {
 		r += cutbrs ? "\n" : "<br>";
 	    }
+	} else {
+	    r += html.substr(tpos);
+	    npos = html.size();
 	}
     }
 
@@ -920,3 +945,73 @@ string cuthtml(const string &html, bool cutbrs) {
 
     return r;
 }
+
+char *utf8_to_str(const char *pin) {
+    int n = 0, i = 0, inlen;
+    unsigned char *result;
+    const unsigned char *in = (unsigned char *) pin;
+
+    if(!in) return NULL;
+
+    inlen = strlen(pin);
+    result = new unsigned char[inlen + 1];
+
+    while (n <= inlen - 1) {
+	long c = (long)in[n];
+	if(c < 0x80) result[i++] = (char)c; else {
+	    if((c & 0xC0) == 0xC0) result[i++] = (char)(((c & 0x03) << 6) | (((unsigned char)in[++n]) & 0x3F));
+	    else if ((c & 0xE0) == 0xE0) {
+		if (n + 2 <= inlen) {
+		    result[i] = (char)(((c & 0xF) << 4) | (((unsigned char)in[++n]) & 0x3F));
+		    result[i] = (char)(((unsigned char)result[i]) | (((unsigned char)in[++n]) & 0x3F));
+		    i++;
+		} else n += 2;
+	    } else if ((c & 0xF0) == 0xF0) n += 3;
+	    else if ((c & 0xF8) == 0xF8)
+		n += 4;
+	    else if ((c & 0xFC) == 0xFC)
+		n += 5;
+	}
+	n++;
+    }
+
+    result[i] = '\0';
+    return (char *) result;
+}
+
+char *str_to_utf8(const char *pin) {
+    int n = 0, i = 0;
+    int inlen;
+    char *result = NULL;
+    const unsigned char *in = (unsigned char *) pin;
+
+    if(!in)
+	return NULL;
+
+    inlen = strlen(pin);
+    result = new char[inlen * 2 + 1];
+
+    while (n < inlen) {
+	long c = (long)in[n];
+	if (c == 27) {
+	    n += 2;
+	    if (in[n] == 'x')
+		n++;
+	    if (in[n] == '3')
+		n++;
+	    n += 2;
+	    continue;
+	}
+
+	if (c < 128)
+	    result[i++] = (char)c;
+	else {
+	    result[i++] = (char)((c >> 6) | 192);
+	    result[i++] = (char)((c & 63) | 128);
+	}
+	n++;
+    }
+
+    result[i] = '\0';
+    return result;
+}
