@@ -137,7 +137,7 @@ motorui::askresult ncursesui::ask(const string &answersallowed, const string &te
     return motorui::no;
 }
 
-void ncursesui::log(const string &text = "") {
+void ncursesui::log(const string &text) {
     bool hl = false;
     string::const_iterator i;
 
@@ -165,7 +165,7 @@ void ncursesui::log(const string &text = "") {
     refresh();
 }
 
-void ncursesui::loadeditfile(const motorui::editfile ef, int options = 0) {
+void ncursesui::loadeditfile(const motorui::editfile ef, int options) {
     ifstream f;
     int i;
     char buf[512];
@@ -237,29 +237,23 @@ void ncursesui::commandline(int argc, char **argv) {
     int r;
     string slong;
 
-    while((r = getopt(argc, argv, "ah-:")) != -1)
-    switch(r) {
-	case 'a':
-	    kintf_graph = 0;
-	    break;
-	case '?':
-	case 'h':
-	    usage();
-	    exit(0);
-	    break;
-    }
-
     for(r = 1; argv[r]; r++) {
 	slong = argv[r];
 
-	if(slong == "--ascii") {
+	if(slong == "--ascii" || slong == "-a") {
 	    kintf_graph = 0;
-	} else if(slong == "--help") {
+
+	} else if((slong == "--debugtty" || slong == "-t") && argv[++r]) {
+	    debugger.forceusetty(argv[r]);
+
+	} else if(slong == "--help" || slong.substr(0, 1) == "-") {
 	    usage();
 	    exit(0);
+
 	} else if(project.empty()) {
-	    project = motorproject(projectname(argv[optind]));
+	    project = motorproject(projectname(slong));
 	    onprojectload();
+
 	}
     }
 }
@@ -269,10 +263,11 @@ void ncursesui::usage() {
     cout << "usage: motor [options] [project name]" << endl <<
     "options are as follows:" << endl <<
     "\t-a, --ascii\tuse ascii characters to draw lines" << endl <<
+    "\t-t, --debugtty\tuse the specified tty for debugging" << endl <<
     "\t-h, --help\tdisplay this help screen" << endl;
 }
 
-const projectname ncursesui::selectproject(mgrmode amode = selectonly, vector<string> templs) {
+const projectname ncursesui::selectproject(mgrmode amode, vector<string> templs) {
     vector<projectname>::iterator i;
     vector<projectname> pnames;
     vector<string>::iterator is;
@@ -383,7 +378,7 @@ const projectname ncursesui::selectproject(mgrmode amode = selectonly, vector<st
     return pname;
 }
 
-string ncursesui::selecttemplate(const string &def = "") {
+string ncursesui::selecttemplate(const string &def) {
     dialogbox db;
     string ret, lw, buf;
     int n, b, nnode, citem, id, cpid = -1;
@@ -1275,7 +1270,7 @@ const string &prompt) {
 	    fselmode = true;
 	    fseloptions |= FSEL_DIRSELECT;
 	    selector.setstartpoint(result);
-	    selwindow.set_title(getcolor(cp_menuhl), _(" enter to select a directory, esc to cancel "));
+	    selwindow.set_title(getcolor(cp_menuhl), _(" space to select a directory, esc to cancel "));
 	    break;
 
 	case motorui::text:
@@ -1348,7 +1343,7 @@ void ncursesui::populatecontentstree(treeview &tree, motorproject &mp, projedita
     tree.setcur(cfid);
 }
 
-bool ncursesui::projectcontents(projeditaction pea, bool setcurrent = true) {
+bool ncursesui::projectcontents(projeditaction pea, bool setcurrent) {
     int n, b, citem, id;
     dialogbox db;
     string buf, head;
@@ -1432,8 +1427,13 @@ bool ncursesui::projectcontents(projeditaction pea, bool setcurrent = true) {
 		if(ar == motorui::yes) {
 		    buf = project.transformfname(projectpaths::relative, buf);
 		    if(find(fold->begin(), fold->end(), buf) == fold->end()) {
-			fold->addfile(motorfile(buf), AF_VCS | AF_CHECKDIR | AF_TAKE);
-			tregen = rc = true;
+			if(fold->addfile(motorfile(buf), AF_VCS | AF_CHECKDIR | AF_TAKE)) {
+			    tregen = rc = true;
+			    db.redraw();
+			} else {
+			    logf(_("Cannot add ~%s~ to the ~%s~ folder"),
+				buf.c_str(), fold->getname().c_str());
+			}
 		    }
 		}
 		break;
@@ -1441,6 +1441,7 @@ bool ncursesui::projectcontents(projeditaction pea, bool setcurrent = true) {
                 if(fold && file) {
 		    fold->removefile(*file);
 		    tregen = rc = true;
+		    db.redraw();
 		}
 		break;
 	    case 2:
@@ -1831,39 +1832,54 @@ bool ncursesui::createproject() {
 
 	if(ret) {
 	    if(rootdir.empty()) {
-	    	log(_("Project root directory must be set"));
+		log(_("Project root directory must be set"));
 		ret = false;
-	    } else if(pname.empty()) {
+	    }
+
+	    if(ret)
+	    if(pname.empty()) {
 		log(_("Project name must be set"));
 		ret = false;
-	    } else if(templname.empty()) {
+	    }
+
+	    if(ret)
+	    if(templname.empty()) {
 		log(_("Template must be set"));
 		ret = false;
-	    } else if(!(mp = projectname(pname)).empty()) {
+	    }
+
+	    if(ret)
+	    if(!(mp = projectname(pname)).empty()) {
 		logf(_("Project named %s already exists"), pname.c_str());
 		ret = false;
-	    } else if(pname.substr(0, 1).find("0123456789") != -1) {
+	    }
+
+	    if(ret)
+	    if(pname.substr(0, 1).find_first_of("0123456789") != -1) {
 		log(_("Project name cannot start with a number"));
 		ret = false;
 	    }
 
-	    if(ret && (mode == cmvcs))
+	    if(ret)
+	    if(mode == cmvcs)
 	    if(vcsroot.empty() || vcsmodule.empty()) {
 		log(_("VCS name, repository and module name must be specified"));
 		ret = false;
             }
 
-	    if(ret && (mode != cmfiles))
+	    if(ret)
+	    if(mode != cmfiles)
 	    if(access(rootdir.c_str(), F_OK))
 	    if(ret = (ask("YNC", _("root directory you specified does not exist. create?")) == motorui::yes)) {
         	mksubdirs(rootdir);
 	    }
 
-	    if(ret && access(rootdir.c_str(), R_OK | W_OK | X_OK)) {
-		ret = false;
+	    if(ret)
+	    if(access(rootdir.c_str(), R_OK | W_OK | X_OK)) {
                 log(_("Access denied for the directory specified"));
+		ret = false;
             }
-	
+
 	    fin = ret;
 	}
     }
@@ -1992,7 +2008,7 @@ void ncursesui::executordone(const string &target, int nerr, int nwarn, int ninf
     }
 }
 
-void ncursesui::projectedit(projeditaction pea, bool setcurrent = true) {
+void ncursesui::projectedit(projeditaction pea, bool setcurrent) {
     bool modified = false;
 
     switch(pea) {
